#ifndef ccbconstants_h
#define ccbconstants_h

/* The TCP/IP port of the CCB telemetry server */

#define CCB_TELEMETRY_PORT 5324

/* The TCP/IP port of the CCB control server */

#define CCB_CONTROL_PORT 5323

/* The maximum number of total-power measurements from any instrument */

#define CCB_MAX_INTEG 64

/* The maximum number of monitor measurements from any instrument */

#define CCB_MAX_MONITOR 16

/* The maximum length of a log message, including the '\0' terminator */

#define CCB_MAX_LOG 128

/* The maximum number of steps in the calibration state machine */

#define CCB_MAX_NCAL 32

/* Set the purge interval of the log message table (seconds) */

#define CCB_LOG_PURGE_DT 60

/*
 * Specify the default monitoring period, expressed as an integer
 * multiple of the integration period.
 */
#define CCB_MONITOR_PERIOD 5

/*
 * Set the maximum number of disimilar messages per statement that can
 * be reported to the manager during each log-table purge interval.
 */
#define CCB_MAX_LOG_VARIANTS 10

/*
 * Set the maximum size of the queue that is used to record integration
 * messages that are to be sent to the manager. Note that each node in
 * the integration queue is about 284 bytes in length.
 */
#define CCB_INTEG_QLEN 10000 /* 10s worth of 1ms integrations = 2.84MB */

/*
 * Set the maximum size of the queue that is used to record monitor
 * messages that are to be sent to the manager. Note that each node in
 * the monitor queue is about (6+CCB_MAX_MONITOR)*4 bytes in length.
 * Since monitoring messages are only meant as a visual indication of
 * the current state of the instrument, there is little point in
 * queuing more than 1 legacy message
 */
#define CCB_MONITOR_QLEN 1

/*
 * Set an upper limit to the number of log messages that can be queued
 * for sending to the manager.
 */
#define CCB_LOG_QLEN 100

/*
 * Set an upper limit to the number of telemetry ping replies that can
 * be queued.
 */
#define CCB_TELEM_LINK_QLEN 1

/*
 * Set a limit on the number of control reply messages that can be queued
 * before old messages start being discarded.
 */
#define CCB_CNTRL_REPLY_QLEN 100

/*
 * Set a limit on the number of control command messages that can be queued
 * before old messages start being discarded.
 */
#define CCB_CNTRL_CMD_QLEN 200

/*
 * Specify the name of the file that lists authorized IP addresses.
 * Note that the directory is specified separately by ccbconfdir.h,
 * which is created by the CCB configure script.
 */
#define CCB_IP_TABLE_FILE "ccb_authorized_ips"

/*
 * The number of nanoseconds in a second.
 */
#define CCB_NS_PER_SEC 1000000000

/*
 * The frequency of the clock used by the CCB hardware, expressed in
 * Hertz. Intervals are communicated with the hardware as multipliers
 * of the period of this clock.
 */
#define CCB_CLOCK_FREQ 10000000   /* f=10MHz, period=100ns */

/*
 * Get the duration of a hardware clock tick expressed in nanoseconds.
 */
#define CCB_NS_PER_TICK (CCB_NS_PER_SEC/CCB_CLOCK_FREQ)

/*
 * Set the backlog managers that are allowed to await connections to
 * the telemetry and control ports of the CCB server. Only one manager
 * should be connecting at a time, so there is no point in supporting
 * a large number of waiting managers. Also, a smaller number reduces
 * the possibility of denial of service attacks, since there is less
 * overhead in rejecting bogus connections if the TCP/IP stack does it
 * without consulting our server.
 */
#define CCB_SERVER_BACKLOG 1

/*
 * Specify the minimum A/D readout interval that can be accomodated by
 * the hardware (x100ns).
 */
#define CCB_MIN_ADC_READOUT_DT 250  /* 25ns */

/*
 * Specify the minimum integration period that can be accomodated by the
 * CCB communications (ns).
 */
#define CCB_MIN_INTEG_DT 1000000  /* 1ms */

/*
 * The number of seconds in a day.
 */
#define CCB_SEC_PER_DAY 86400

/*
 * The number of microseconds per second.
 */
#define CCB_USEC_PER_SEC 1000000

/*
 * The number of nanoseconds per second.
 */
#define CCB_NS_PER_SEC 1000000000

/*
 * The number of nanoseconds per microsecond.
 */
#define CCB_NS_PER_USEC 1000

#endif
