#!@PERL@ -w
#-----------------------------------------------------------------------
# Usage:
#  fill_logids <existing_maximum_logid> files...
#-----------------------------------------------------------------------

use File::Copy;   # Import the file-copying command.

# The first command-line argument is the highest log ID used so far,
# as determined by running `find_max_logid *.c`.

$logid = shift;

# Check that the first argument is an integer log ID.

if(!defined $logid || $logid !~ /^\d+$/) {
  die "The first argument must be the maximum log ID that is currently in use.\n";
}

# Check that each of the files specified on the command-line is readable,
# and that they are .c files.

foreach $file (@ARGV) {
  if( ! -f $file || ! -r $file || $file !~ /\.c$/ ) {
    die "$file isn't a readable .c file\n"
  }
}

# Process each of the specified files, writing the filtered version of
# each file temporarily to a temporary file, then replacing the
# original with this temporary file.

foreach $file (@ARGV) {
  open(FILE, "<$file") or die "$!\n";      # Open the original input file.
  $tmpfile = "$file.tmp";
  open(TMP, ">$tmpfile") or die "$!\n";   # Open the temporary output file.

  # Mark the file as unmodified.

  $modified = 0;

  # For each line in the file, replace all occurences of '?' within
  # LOGID() macros with the next highest value of the log ID. Then
  # print out the line, regardless of whether it was modified.

  while($line=<FILE>) {
    $index=0;
    while(($index=index($line,"LOGID(?)",$index)) >= 0) {
      substr($line,$index+6,1) = ++$logid;
      $index++;
      $modified = 1;
    }

    # Write the possibly modified line to the temporary output file.

    print TMP $line;
  }

  # Did any log statements get modified?

  if($modified) {

    # Backup the original file.

    copy $file, "$file~";

    # Replace the original file with the processed version.

    rename $tmpfile, $file;

  } else {

    unlink $tmpfile;  # Get rid of the temporary file.

  }
}

